package VMOMI::GuestRegKeyWowSpec;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
